#
# spec file for package parlatype
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define c_lib   libparlatype5
Name:           parlatype
Version:        3.1
Release:        1.7
Summary:        GNOME audio player for transcriptions
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://gkarsay.github.io/parlatype/
Source:         https://github.com/gkarsay/parlatype/releases/download/v%{version}/parlatype-%{version}.tar.gz
BuildRequires:  AppStream-devel
BuildRequires:  automake
BuildRequires:  glib2-devel >= 2.58
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk3-devel
BuildRequires:  intltool
BuildRequires:  iso-codes-devel
BuildRequires:  libtool
BuildRequires:  meson >= 0.47.2
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
Requires:       %{c_lib} = %{version}
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-good
Requires:       gstreamer-plugins-ugly
Recommends:     %{name}-lang

%description
Parlatype is a minimal audio player for manual speech transcription, written for the GNOME desktop environment. It plays audio sources to transcribe them in your favourite text application.

%package -n libparlatype-devel
Summary:        Development files for parlatype
Group:          Development/Libraries/C and C++
Requires:       %{c_lib} = %{version}

%description -n libparlatype-devel
Parlatype ships its own library, libparlatype, which provides a GStreamer backend (PtPlayer) and a waveviewer widget (PtWaveviewer) which is a GtkWidget.

%package -n %{c_lib}
Summary:        Library for parlatype
Group:          System/Libraries
Recommends:     libparlatype-lang

%description -n %{c_lib}
Parlatype ships its own library, libparlatype, which provides a GStreamer backend (PtPlayer) and a waveviewer widget (PtWaveviewer) which is a GtkWidget.

%lang_package

%prep
%setup -q

%build
%meson -Ddeepspeech=false -Dpocketsphinx=false
%meson_build

%install
%meson_install

%find_lang %{name}
%find_lang org.parlatype.Parlatype %{no_lang_C} %{name}.lang
%find_lang libparlatype5

%post -n %{c_lib} -p /sbin/ldconfig
%postun -n %{c_lib} -p /sbin/ldconfig

%files
%license COPYING
%doc NEWS README.md
%{_bindir}/parlatype
%{_mandir}/man1/parlatype.1%{?ext_man}
%{_datadir}/help/C/org.parlatype.Parlatype/
%{_datadir}/icons/hicolor/
%{_datadir}/applications/org.parlatype.Parlatype.desktop
%{_datadir}/dbus-1/services/org.parlatype.Parlatype.service
%{_datadir}/glib-2.0/schemas/org.parlatype.Parlatype.gschema.xml
%{_datadir}/metainfo/org.parlatype.Parlatype.appdata.xml

%files -n libparlatype-devel
%{_libdir}/libparlatype.so
%{_includedir}/parlatype/
%{_libdir}/pkgconfig/parlatype.pc

%files -n %{c_lib}
%{_libdir}/libparlatype.so.*

%files lang -f %{name}.lang

%files lang -f libparlatype5.lang

%changelog
* Mon Jan 10 2022 Michael Vetter <mvetter@suse.com>
- Update to 3.1:
  * New: Added MPRIS interface, fix #86
  * New: Switched to Weblate for translations
  * Fix: Setting initial position failed in some cases
  * Fix: Build and tests failed on WIN32
  * Fix: Help pages for Preferences Dialog were not updated
  * Fix: Adapt to builds without ASR
- Remove parlatype-asr.patch: upstreamed
* Thu Nov  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Move translated help to -lang package.
  + Using the find_lang macros, properly tag the translations and
    avoid conflicts with system base directories.
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Add parlatype-asr.patch:
  Don't install asr files if built without asr
  See https://github.com/gkarsay/parlatype/issues/88
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 3.0:
  * New: ASR plugin for Mozilla DeepSpeech (needs DeepSpeech at compile time)
  * New: Removed possibility to output ASR results to random applications using
    assistive technologies and removed internal textpad. ASR results are
    emitted through D-Bus only and applications like Parlatype LibreOffice
    Extension can listen to them. Removed (now unnecessary option)
  - -with-asr.
  * New: Rewritten ASR preferences page with Configs per model.
  * New: Internal GStreamer plugins are now private to the lib, which should
    eliminate all errors related to GStreamer registry.
  * New: Flatpak builds Mozilla DeepSpeech 0.9.
  * New: New App Icon by Tobias Bernard
  * New: Many preparations for GTK 4, maintenance work, modularizing and
    refactoring code, increased test coverage, fixed memory leaks.
  * New: Main development branch is now called "main".
  * New: Version string includes git commit if applicable
  * Fix: Don't mirror waveform in RTL layouts, they expect it to be like in LTR.
  * Changed dependencies:
  - Removed atspi-2
  - Added iso-codes
  - Raised glib-2.0 to 2.58
  - Added optional deepspeech
  * Updated translations
* Mon Jun 22 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.1:
  * New: Mute/unmute volume by clicking on the volume icon with the pointer’s
    secondary button (usually right mouse button).
  * New: With Pulseaudio Parlatype doesn’t change the system volume anymore,
    just its own application specific volume.
  * New: With Pulseaudio Parlatype picks up the last used volume level.
  * New: Volume icon/button is insensitive as long as there is no media loaded.
  * New: Don’t reopen already opened files.
  * New: Set a default window height and in Preferences default to “Remember
    window’s size”.
  * Fix: ASR assistant dialog could not be used at all, a regression introduced
    in version 2.0. However, ASR is not recommended in its current state
    and plans are to rewrite it.
  * Fix: D-Bus interface for decreasing speed was doing the opposite.
  * Fix: Many fixes to Windows (win32) port, achieving feature parity with the
    Linux/UNIX version:
  - Fix: Parlatype icon not loaded
  - Fix: Help pages not displayed
  - Fix: Don’t show mediakeys help page (Linux only)
  - Fix: Volume changes delayed for a few seconds
  - New: Ensure there is only one instance running.
  - New: Added hotkeys support (hardcoded for dedicated keyboard buttons
    Play/Pause, Stop, Previous Track, Next Track)
  - New: Added win32 specific interprocess communication, thus enabling
    the LibreOffice extension
  * Update translations
- Remove parlatype-2.0-asr.patch: contained in release
* Fri Mar 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.0:
  * New: Waveform is loaded on-the-fly, there is no blocking progress
    dialog. This brings an API bump in libparlatype.
  * New: Waveform can be changed continuously instead of in bumps.
  * New: Application ID has been changed to org.parlatype.Parlatype and the
    homepage moved to https://www.parlatype.org.
  * New: LibreOffice helpers (macros) have been split from the main
    repository and turned into a LibreOffice extension.
    The extension is released at
    https://github.com/gkarsay/parlatype-libreoffice-extension/releases/tag/v2.0
  * New: New D-Bus method GetURI to get currently playing file's URI.
  * New: Internal modularization (PtController objects control Parlatype).
  * New: Event handling is more compatible with GTK 4.
  * New: Parlatype builds on Windows, there is no feature parity though.
- Add parlatype-2.0-asr.patch: Fix regression in the ASR assistant dialog.
* Mon Sep  2 2019 mvetter@suse.com
- Update to 1.6.2:
  * Update time label only if time has changed.
  * Various fixes or improvements for the build system
  * Fixed pkg-config cflags
  * Fixed failing unit test
  * Fixed extern C declarations for C++
  * Added Meson configuration message
  * New or updated languages: es, hu, lt
* Thu Jul 18 2019 mvetter@suse.com
- Update to 1.6.1:
  * New: Automatic speech recognition (ASR) is now disabled by default
  and it’s only shown, if parlatype is launched with the new parameter --with-asr
  * New: Parlatype can be built without ASR (build option asr=false)
  * New: libreoffice helpers’ AppStream ID renamed (hyphen instead of underscore)
  * Fix: Initialize i18n for library, fixes not shown translations in
  Flatpak or non-standard prefixes
  * Fix: All memory leaks discovered with Valgrind in test suite
  * Fix: All issues discovered with Clang Static Analyzer
  * Add and update translations
* Thu Aug 30 2018 mvetter@suse.com
- Move gstreamer-plugins-* from BuildRequires to Requires
* Wed Aug 29 2018 mvetter@suse.com
- Install desktop file, as the 1.5.6 one is valid now
* Thu Aug 23 2018 mvetter@suse.com
- Update to 1.5.6:
  * Animate scrolling when using keybindings
  * Change desktop entry category to Audio/Video instead of Utilities
  * Fix a build warning on most architectures other than amd64
  * New or updated translations:
  - fr: Georgelemental
* Thu Aug 23 2018 mvetter@suse.com
- Add libparlatype lang package
* Mon Jun 25 2018 mvetter@suse.com
- Split libparlatype into own subpackage
- Have seperate lang package
* Sun Jun 24 2018 mvetter@suse.com
- Remove desktop file for now, to prevent non valid error
* Tue Jun 19 2018 mvetter@suse.com
- Inital package for openSUSE in version 1.5.5
